==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/enums/VirtualNetworkGatewaySkuName.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * Gateway SKU name.
 */
public enum class VirtualNetworkGatewaySkuName(
    public val javaValue: com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuName,
) : ConvertibleToJava<com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuName> {
    Basic(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuName.Basic),
    HighPerformance(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuName.HighPerformance),
    Standard(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuName.Standard),
    UltraPerformance(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuName.UltraPerformance),
    VpnGw1(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuName.VpnGw1),
    VpnGw2(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuName.VpnGw2),
    VpnGw3(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuName.VpnGw3),
    VpnGw4(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuName.VpnGw4),
    VpnGw5(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuName.VpnGw5),
    VpnGw1AZ(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuName.VpnGw1AZ),
    VpnGw2AZ(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuName.VpnGw2AZ),
    VpnGw3AZ(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuName.VpnGw3AZ),
    VpnGw4AZ(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuName.VpnGw4AZ),
    VpnGw5AZ(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuName.VpnGw5AZ),
    ErGw1AZ(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuName.ErGw1AZ),
    ErGw2AZ(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuName.ErGw2AZ),
    ErGw3AZ(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuName.ErGw3AZ),
    ;

    override fun toJava(): com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuName =
        javaValue

    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuName):
            VirtualNetworkGatewaySkuName =
            VirtualNetworkGatewaySkuName.values().first { it.javaValue == javaType }
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/network/kotlin/enums/VirtualNetworkGatewaySkuName.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * Gateway SKU name.
 */
public enum class VirtualNetworkGatewaySkuName(
    public val javaValue: com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuName,
) : ConvertibleToJava<com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuName> {
    Basic(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuName.Basic),
    HighPerformance(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuName.HighPerformance),
    Standard(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuName.Standard),
    UltraPerformance(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuName.UltraPerformance),
    VpnGw1(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuName.VpnGw1),
    VpnGw2(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuName.VpnGw2),
    VpnGw3(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuName.VpnGw3),
    VpnGw4(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuName.VpnGw4),
    VpnGw5(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuName.VpnGw5),
    VpnGw1AZ(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuName.VpnGw1AZ),
    VpnGw2AZ(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuName.VpnGw2AZ),
    VpnGw3AZ(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuName.VpnGw3AZ),
    VpnGw4AZ(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuName.VpnGw4AZ),
    VpnGw5AZ(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuName.VpnGw5AZ),
    ErGw1AZ(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuName.ErGw1AZ),
    ErGw2AZ(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuName.ErGw2AZ),
    ErGw3AZ(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuName.ErGw3AZ),
    ;

    override fun toJava(): com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuName =
        javaValue

    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuName): VirtualNetworkGatewaySkuName =
            VirtualNetworkGatewaySkuName.values().first { it.javaValue == javaType }
    }
}
